from django.contrib.auth.models import User
from django.db import models
from django.db.models.signals import post_save
from django.dispatch import receiver
from django.utils import timezone


class StravaToken(models.Model):
    user = models.OneToOneField(User, on_delete=models.CASCADE)
    strava_access_token = models.CharField(max_length=255, blank=True, null=True)
    strava_refresh_token = models.CharField(max_length=255, blank=True, null=True)
    strava_expires_at = models.IntegerField(blank=True, null=True)  # Unix timestamp
    strava_athlete_id = models.IntegerField(blank=True, null=True)
    
    def __str__(self):
        return f"{self.user.username}'s stravatoken"

    def is_expired(self):
        return self.strava_expires_at is None or self.strava_expires_at < timezone.now().timestamp()

# Automatically create or update user stravatoken
@receiver(post_save, sender=User)
def create_or_update_user_stravatoken(sender, instance, created, **kwargs):
    if created:
        StravaToken.objects.create(user=instance)
    instance.stravatoken.save()